@@ -1937,7 +1937,7 @@ to_ts!(
     "
     module Top {
         module A__2 {
-            export function b__0() {
+            export function b__3() {
             }
         }
         A__2.b();
@@ -1989,9 +1989,9 @@ to_ts!(
         interface B__2 {
             m__0: string;
         }
-        var x: any;
-        var y = x as A__2<B__2>[];
-        var z = y[0].m;
+        var x__2: any;
+        var y__2 = x__2 as A__2<B__2>[];
+        var z__2 = y__2[0].m;
     }
     
     "
@@ -2468,24 +2468,41 @@ to_ts!(
         get [`hello ${a} bye`]() { return 0; }
     }
     ",
-    "
+    r#"
     var s: string;
     var n: number;
     var a: any;
     var v = {
-        get [s]() { return 0; },
-        set [n](v__2) { },
-        get [s + s]() { return 0; },
-        set [s + n](v__2) { },
-        get [+s]() { return 0; },
-        set [\"\"](v__2) { },
-        get [0]() { return 0; },
-        set [a](v__2) { },
-        get [<any>true]() { return 0; },
-        set [`hello bye`](v__2) { },
-        get [`hello ${a} bye`]() { return 0; }
-    }
-    "
+        get [s] () {
+            return 0;
+        },
+        set [n] (v__2){
+        },
+        get [s + s] () {
+            return 0;
+        },
+        set [s + n] (v__3){
+        },
+        get [+s] () {
+            return 0;
+        },
+        set [""] (v__4){
+        },
+        get [0] () {
+            return 0;
+        },
+        set [a] (v__5){
+        },
+        get [<any>true] () {
+            return 0;
+        },
+        set [`hello bye`] (v__6){
+        },
+        get [`hello ${a} bye`] () {
+            return 0;
+        }
+    };
+    "#
 );
 
 to!(
@@ -2686,3 +2703,137 @@ to_ts!(
     type A = {}
     "#
 );
+
+to_ts!(
+    ts_simple,
+    "
+    let a;
+    {
+        let a;
+        let b;
+        {
+            let a;
+            let b;
+            let c;
+        }
+        {
+            let a;
+            let b;
+            let c;
+        }
+    }
+    ",
+    "
+    let a;
+    {
+        let a__2;
+        let b__2;
+        {
+            let a__3;
+            let b__3;
+            let c__3;
+        }
+        {
+            let a__4;
+            let b__4;
+            let c__4;
+        }
+    }
+    "
+);
+
+to!(
+    ts_es5_for_of_27,
+    "
+    for (var {x: a = 0, y: b = 1} of [2, 3]) {
+        a;
+        b;
+    }
+    ",
+    "
+    for (var {x: a = 0, y: b = 1} of [2, 3]) {
+        a;
+        b;
+    }
+    "
+);
+
+to_ts!(
+    ts_if_do_while_statements_01,
+    "
+    module M {
+        export class A {
+            name: string;
+        }
+    
+        export function F2(x: number): string { return x.toString(); }
+    }
+    
+    module N {
+        export class A {
+            id: number;
+        }
+    
+        export function F2(x: number): string { return x.toString(); }
+    }
+    ",
+    "
+    module M {
+        export class A__2 {
+            name__0: string;
+        }
+        export function F2__2(x__3: number): string {
+            return x__3.toString();
+        }
+    }
+    module N {
+        export class A__4 {
+            id__0: number;
+        }
+        export function F2__4(x__5: number): string {
+            return x__5.toString();
+        }
+    }
+    "
+);
+
+to_ts!(
+    ts_type_parameter_used_as_type_parameter_contraint_01,
+    "
+    var f3 = <T, U extends T>(x: T, y: U) => {
+        function bar<V extends T, W extends U>() {
+            var g = <X extends W, Y extends V>(a: X, b: Y): T => {
+                x = y;
+                return y;
+            }
+        }
+    }
+
+    var f4 = <U extends T, T>(x: T, y: U) => {
+        function bar<V extends T, W extends U>() {
+            var g = <X extends W, Y extends V>(a: X, b: Y): T => {
+                x = y;
+                return y;
+            }
+        }
+    }
+    ",
+    "
+    var f3 = <T__2, U__2 extends T__2>(x__2: T__2, y__2: U__2)=>{
+        function bar__2<V__3 extends T__2, W__3 extends U__2>() {
+            var g__3 = <X__4 extends W__3, Y__4 extends V__3>(a__4: X__4, b__4: Y__4)=>{
+                x__2 = y__2;
+                return y__2;
+            };
+        }
+    };
+    var f4 = <U__5 extends T__5, T__5>(x__5: T__5, y__5: U__5)=>{
+        function bar__5<V__6 extends T__5, W__6 extends U__5>() {
+            var g__6 = <X__7 extends W__6, Y__7 extends V__6>(a__7: X__7, b__7: Y__7)=>{
+                x__5 = y__5;
+                return y__5;
+            };
+        }
+    };
+    "
+);
